\name{simsel.linear}
\alias{simsel.linear}
\title{The linear SimSel algorithm}
\description{
Runs the linear SimSel algorithm and plots the RSS against the H(1,1)-element for each variable. See 'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis) for details.
}
\usage{
simsel.linear(X, Y, max = 0.1, step = 0.001)
}
\arguments{
  \item{X}{Independent variables. NAs not allowed (yet).}
  \item{Y}{Dependent variable}
  \item{max}{The maximum value of the lambdas}
  \item{step}{The step size of the lambdas}
}
\details{
  See 'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)
}
\value{
Only graphics.
}
\references{'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)}
\seealso{\code{\link{single.simsel.linear}}, \code{\link{single.simsel.quadratic}}, \code{\link{simsel.quadratic}}}
\examples{
	########################################################
	# Linear, uncorrelated data with no measurement errors #
	########################################################
	# Construct uncorrelated independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a linear way on the dependent variables
	Y <- X\%*\%c(1, 0, 1, 0, 0)
	# Add roughly 10 percent error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.05)
	# Run SimSel 1 times and plot graph the results.
	simsel.linear(X, Y)

	#####################################################	
	# Linear, uncorrelated data with measurement errors #
	#####################################################
	# Construct uncorrelated independent variables
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a linear way on the dependent variables
	Y <- X\%*\%c(1, 0, 1, 0, 0)
	# Add roughly 10 percent error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.05)
	# Add roughly 10 percent error added to the independent variables
	for(i in 1:ncol(X))	{
		X[,i] <- X[,i] + rnorm(nrow(X), 0, 0.05)
	}
	# Run SimSel 1 times and plot graph the results.
	simsel.linear(X, Y)

	######################################################	
	# Linear, correlated data with no measurement errors #
	######################################################
	# Construct moderately correlated independent variables
	randomSigma <- diag(5)
	for(i in 2:nrow(randomSigma))	{
		for(j in 1:i-1)	{
			tmp <- runif(1, -0.5, 0.5)
			randomSigma[i, j] <- tmp
			randomSigma[j, i] <- tmp
		}
	}
	randomSigma <- posdefify(randomSigma)
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), randomSigma)
	# Construct dependent variable that depends in a linear way on the dependent variables	
	Y <- X\%*\%c(1, 0, 1, 0, 0)
	# Add roughly 10 percent error added to the independent variables
	Y <- Y + rnorm(nrow(Y), 0, 0.05)
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient	
	simsel.linear(X, Y)

	###################################################	
	# Linear, correlated data with measurement errors #
	###################################################
	# Construct moderately correlated independent variables
	randomSigma <- diag(5)
	for(i in 2:nrow(randomSigma))	{
		for(j in 1:i-1)	{
			tmp <- runif(1, -0.5, 0.5)
			randomSigma[i, j] <- tmp
			randomSigma[j, i] <- tmp
		}
	}
	randomSigma <- posdefify(randomSigma)
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), randomSigma)
	# Construct dependent variable that depends in a linear way on the dependent variables		
	Y <- X\%*\%c(1, 0, 1, 0, 0)
	# Add roughly 10 percent error added to the independent variables	
	Y <- Y + rnorm(nrow(Y), 0, 0.05)
	# Add roughly 10 percent error added to the independent variables	
	for(i in 1:ncol(X))	{
		X[,i] <- X[,i] + rnorm(nrow(X), 0, 0.05)
	}
	# Run SimSel 1 times and plot graph the results.
	simsel.linear(X, Y)

## The function is currently defined as
function(X, Y, max=0.1, step=0.001)	{
	RSS <- NULL
	H <- NULL
	for(i in 1:ncol(X))	{
		tmp <- single.simsel.linear(X, Y, max, step, i)
		RSS <- cbind(RSS, tmp$RSS)
		H <- cbind(H, tmp$H)
		s <- summary(lm(tmp$RSS ~ tmp$H))
		f <- s[[10]][1]	# F-stat
		r2 <- s[[9]][1]	# Adjusted R-squared
		cat("Variable", i, " R-squared", r2, "\n")
		cat("            F-statistics", f, "\n")
	}
	cc <- rainbow(ncol(X))
	matplot(H, RSS, pch = 1:ncol(X), col = cc)
	for(i in 1:ncol(X))	{
		abline(lm(RSS[,i] ~ H[,i]), col = cc[i])
	}
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{NA}
