\name{simsel.quadratic}
\alias{simsel.quadratic}
\title{The quadratic SimSel algorithm}
\description{
Runs the quadratic SimSel algorithm and plots the RSS against lambda for each variable. See 'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis) for details.
}
\usage{
simsel.quadratic(X, Y, max = 0.1, step = 0.001)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{X}{Independent variables. NAs not allowed (yet).}
  \item{Y}{Dependent variable}
  \item{max}{The maximum value of the lambdas}
  \item{step}{The step size of the lambdas}
}
\details{
Please see 'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)
}
\value{
	Only graphics.
}
\references{'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)}
\seealso{\code{\link{single.simsel.linear}}, \code{\link{simsel.linear}}, \code{\link{single.simsel.quadratic}}}
\examples{
	###########################################################
	# Nonlinear, uncorrelated data with no measurement errors #
	###########################################################
	# Construct independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Run SimSel 1 times and graph the results
	simsel.linear(X, Y)

	########################################################	
	# Nonlinear, uncorrelated data with measurement errors #
	########################################################
	# Construct independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% error to dependent variable	
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Add roughly 10% error added to the dependent variable
	for(i in 1:ncol(X))	{
		X[,i] <- X[,i] + rnorm(nrow(X), 0, 0.05)
	}
	# Run SimSel 1 times and graph the results
	simsel.linear(X, Y)

	#########################################################	
	# Nonlinear, correlated data with no measurement errors #
	#########################################################
	# Construct moderately correlated independent variables
	randomSigma <- diag(5)
	for(i in 2:nrow(randomSigma))	{
		for(j in 1:i-1)	{
			tmp <- runif(1, -0.5, 0.5)
			randomSigma[i, j] <- tmp
			randomSigma[j, i] <- tmp
		}
	}
	randomSigma <- posdefify(randomSigma)
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), randomSigma)
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% error to dependent variable	
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Run SimSel 1 times and graph the results
	simsel.linear(X, Y)

	######################################################	
	# Nonlinear, correlated data with measurement errors #
	######################################################
	# Construct moderately correlated independent variables
	randomSigma <- diag(5)
	for(i in 2:nrow(randomSigma))	{
		for(j in 1:i-1)	{
			tmp <- runif(1, -0.5, 0.5)
			randomSigma[i, j] <- tmp
			randomSigma[j, i] <- tmp
		}
	}
	randomSigma <- posdefify(randomSigma)
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), randomSigma)
	# Construct dependent variable that depends in a nonlinear way on the dependent variables
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% errors to dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Add roughly 10% errors to independent variables
	for(i in 1:ncol(X))	{
		X[,i] <- X[,i] + rnorm(nrow(X), 0, 0.05)
	}
	# Run SimSel 1 times and graph the results
	simsel.linear(X, Y)

## The function is currently defined as
function(X, Y, max=0.1, step=0.001)	{
	RSS <- NULL
	LAMBDA <- NULL
	for(i in 1:ncol(X))	{
		tmp <- single.simsel.quadratic(X, Y, max, step, i)
		RSS <- cbind(RSS, tmp$RSS)
		LAMBDA <- cbind(LAMBDA, tmp$lambda)		
		s <- summary(lm(tmp$RSS ~ tmp$lambda))
		f <- s[[10]][1]	# F-stat
		r2 <- s[[9]][1]	# Adjusted R-squared
		cat("Variable", i, " R-squared", r2, "\n")
		cat("            F-statistics", f, "\n")
	}
	cc <- rainbow(ncol(X))
	matplot(LAMBDA, RSS, pch = 1:ncol(X), col = cc)
	for(i in 1:ncol(X))	{
		abline(lm(RSS[,i] ~ LAMBDA[,i]), col = cc[i])
	}
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{NA}
